@@ -2,6 +2,7 @@ import unittest
 import os
 import logging
 import sys
+import subprocess
 
 import interface
 import testcase
@@ -25,15 +26,12 @@ def drive_dd_file(dd_file_full_path):
     test_suite_result = text_test_runner.run(test_suite)
     print test_suite_result
     log.debug('printing to files')
-    docdriven_interface.print_to_files(dd_all_response=True)
-
-
+    interface.print_to_files(docdriven_interface, include_response=True)
 
 
 def read_driven_docs_file(root_dir):
     log.debug('root_dir: '+root_dir)
     dd_filename = os.path.join(root_dir, 'DRIVEN_DOCS.txt')
-    # try:
     log.debug('trying to open: '+dd_filename)
     with open(dd_filename) as driven_docs_file:
         log.debug('looping through lines in: '+dd_filename)
@@ -54,20 +52,6 @@ def read_driven_docs_file(root_dir):
                     full_filepath = filepath
                 log.debug('found normal full_filepath; initializing interface: '+full_filepath)
                 drive_dd_file(full_filepath)
-                # log.debug('got down here')
-    # except IOError:
-    #     raise IO
-    #     # this means we could not successfully open a DRIVEN_DOCS.txt file in that directory
-    #     files = os.listdir(root_dir)
-    #     log.debug('DRIVEN_DOCS.txt file not located in '+root_dir)
-    #     log.debug('looking for *.dd files in '+root_dir)
-    #     for f in files:
-    #         if os.path.isdir(f):
-    #             continue
-    #         else:
-    #             if f.endswith('.dd'):
-    #                 log.debug('found '+str(f))
-    #                 drive_dd_file(f)
 
 
 dd_home = os.environ.get('DOC_DRIVEN_HOME')
@@ -76,4 +60,6 @@ if not dd_home:
 if not dd_home:
     dd_home = os.environ.get('HOME')
 read_driven_docs_file(dd_home)
+subprocess.call('/Users/Jon/dev/docdriven/publisher.sh')
+
 
