@@ -2,6 +2,8 @@ import json
 import logging
 import datetime
 import os
+import pprint
+from jsonschema import validate
 
 from _dd_interface_util import title2filename
 
@@ -24,6 +26,10 @@ POST_REPORT = 10
 CHAPTER = 20
 
 
+ch_count = 1
+ch_route_count = 1
+
+
 class DrivenDoc(object):
     def __init__(self, root_dir, filename):
         self.root_dir = root_dir
@@ -47,11 +53,9 @@ class DrivenDoc(object):
         if self.introduction:
             outfile.write('\n\n')
             self.introduction.print_all_to_file(outfile, response)
-        chapter_tracker=0
         for chapter in self.chapter_list:
             outfile.write('\n\n')
             chapter.print_all_to_file(outfile, response)
-            chapter_tracker += 1
         if self.conclusion:
             outfile.write('\n\n')
             self.conclusion.print_all_to_file(outfile, response)
@@ -104,7 +108,7 @@ class DrivenDoc(object):
     def print_ch_status_report(self, ch_status_file):
         ch_status_file.write(self.title+'\n')
         if self.date:
-            ch_status_file.write('% '+datetime.datetime.now().strftime('%A, %B %d, %I:%M:%S %p %z')+'\n\n')
+            ch_status_file.write(datetime.datetime.now().strftime('%A, %B %d, %I:%M:%S %p %z')+'\n\n')
         if self.introduction:
             self.introduction.print_to_ch_status_file(ch_status_file)
 
@@ -164,36 +168,6 @@ class DrivenDoc(object):
                 else:
                     raise Exception('No current chapter set when line received: '+line)
 
-    def print_to_files(self, dd_all_response):
-        filepath = os.path.join(self.root_dir, self.filename)
-        status_filepath = os.path.join(self.root_dir, 'status/')
-        status_filepath = os.path.join(status_filepath, title2filename(self.title))
-
-        dd_all_file = open(filepath[:len(filepath)-3]+'.all.dd', 'w')
-        self.print_all_to_file(dd_all_file, dd_all_response)
-        dd_all_file.close()
-
-        self.print_nav_to_file()
-
-        status_filepath = status_filepath+'.status'
-        try:
-            os.remove(status_filepath)  # delete it if it already existed
-        except:
-           pass
-        status_report = open(status_filepath, 'w').close()  # this looks like some kind of ugly hack
-        status_report = open(status_filepath, 'w')
-        self.print_status_report(status_report)
-        status_report.close()
-
-        ch_status_filepath = status_filepath.replace('.status', '.ch.status')
-        try:
-            os.remove(ch_status_filepath) # delete it if it already existed
-        except:
-            pass
-        ch_status_file = open(ch_status_filepath, 'w').close()
-        ch_status_file = open(ch_status_filepath, 'w')
-        self.print_ch_status_report(ch_status_file)
-        ch_status_file.close()
 
 
 class StatusReport(object):
@@ -270,13 +244,14 @@ class AbstractDocUnit(object):
                 else:
                     raise Exception('Unknown class type: '+self.__class__.__name__)
 
-    def runtime_exec(self, response):
+    def runtime_exec(self, config_predict_response_tuple_list):
         # print 'ADJUSTING FOR NEXT CONFIG - BEGIN'
-        runtime_config = {}
-        runtime_reply = {}
+        this_result = config_predict_response_tuple_list[-1][2]
+        next_config = None
+        next_predict = None
         exec self.sections[RUNTIME]
         # print 'ADJUSTING FOR NEXT CONFIG - FINISHED'
-        return (runtime_config, runtime_reply)
+        return (next_config, next_predict)
 
     def report_stamp(self, code, level, timestamp, speed=0.0, note=None):
         isoformat = timestamp.isoformat()
@@ -343,7 +318,8 @@ class AbstractDocUnit(object):
             doc_string += self.pretty_json(self.sections[CONFIG])+'\n'
             doc_string += '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
         else:
-            doc_string += '#### config/\n'
+            # doc_string += '#### config/\n'
+            pass
 
         if len(self.sections[POST_CONFIG]) > 0:
             doc_string += self.sections[POST_CONFIG]
@@ -354,7 +330,8 @@ class AbstractDocUnit(object):
             doc_string += self.pretty_json(self.sections[PREDICT])+'\n'
             doc_string += '\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
         else:
-            doc_string += '#### predict/\n'
+            # doc_string += '#### predict/\n'
+            pass
 
         if len(self.sections[POST_PREDICT]) > 0:
             doc_string += self.sections[POST_PREDICT]
@@ -365,7 +342,8 @@ class AbstractDocUnit(object):
             doc_string += self.pretty_json(self.sections[RESPONSE])+'\n'
             doc_string += '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
         else:
-            doc_string += '#### response/\n'
+            # doc_string += '#### response/\n'
+            pass
 
         if len(self.sections[POST_RESPONSE]) > 0:
             doc_string += self.sections[POST_RESPONSE]
@@ -376,7 +354,8 @@ class AbstractDocUnit(object):
             doc_string += self.sections[RUNTIME]+'\n'
             doc_string += '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
         else:
-            doc_string += '#### runtime/\n'
+            # doc_string += '#### runtime/\n'
+            pass
 
         if len(self.sections[POST_RUNTIME])>0:
              doc_string += self.sections[POST_RUNTIME]
@@ -387,7 +366,8 @@ class AbstractDocUnit(object):
             doc_string += self.pretty_json(self.sections[REPORT])+'\n'
             doc_string += '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
         else:
-            doc_string += '#### report/\n'
+            # doc_string += '#### report/\n'
+            pass
 
         if len(self.sections[POST_REPORT])>0:
             doc_string += self.sections[POST_REPORT]
@@ -395,11 +375,16 @@ class AbstractDocUnit(object):
         return doc_string
 
     def as_ch_report_string(self):
+        titl = self.title
+        if self.__class__.__name__ == 'RouteDocUnit':
+            index = self.title[1:].find('/')
+            if index > 0:
+                titl = self.title[index+1:]
         if len(self.sections[REPORT]) < 1:
-            return 'BLANK'.ljust(8)+' '+self.title
+            return 'BLANK'.ljust(8)+' 6 '+titl
         else:
             report_stamp = json.loads(self.sections[REPORT])
-            return report_stamp['code'].ljust(8)+' '+self.title
+            return report_stamp['code'].ljust(8)+' '+str(report_stamp['level'])+' '+titl
 
     def pretty_json(self, json_string):
         try:
@@ -434,6 +419,13 @@ class AbstractDocUnit(object):
                 self.CODE = False
                 if self.code_index != RUNTIME:
                     self.sections[self.code_index] = self.pretty_json(self.sections[self.code_index])
+                    # if self.code_index == PREDICT:
+                        # try:
+                        #     validate(self.sections[self.code_index], )
+                        # except Exception, e:
+                        #     print 'Invalid JSON schema in predict section for title: '+self.title
+                        #     raise e
+
             elif self.is_text(line):
                 self.sections[self.text_index] += line.rstrip()+'\n'
             elif self.CODE:
@@ -498,7 +490,10 @@ class RouteDocUnit(AbstractDocUnit):
         super(RouteDocUnit, self).__init__(title, chapter.key_filepath)
 
     def print_all_to_file(self, outfile, response=True):
-        outfile.write('\n## '+self.title+'\n')
+        global ch_count
+        global ch_route_count
+        outfile.write('\n## '+self.title+' {#ch-'+str(ch_count)+'-route-'+str(ch_route_count)+'}\n')
+        ch_route_count += 1
         outfile.write(self.as_string(response))
 
 
@@ -522,10 +517,14 @@ class ChapterDocUnit(AbstractDocUnit):
             self.current_doc_unit.consume_line(line, from_filepath)
 
     def print_all_to_file(self, outfile, response=True):
-        outfile.write('# '+self.title+'\n')
+        global ch_count
+        global ch_route_count
+        ch_route_count = 1
+        outfile.write('# '+self.title+' {#ch-'+str(ch_count)+'}\n')
         outfile.write(self.as_string(response))
         for route in self.route_list:
             route.print_all_to_file(outfile, response)
+        ch_count += 1
 
     def print_nav_to_file(self):
         chapter_dir = os.path.join(self.doc_root_dir, 'chapter/')
@@ -558,4 +557,41 @@ class ChapterDocUnit(AbstractDocUnit):
         ch_status_file.write('\n')
 
 
+    def as_string(self, response=True):
+        doc_string = ''
+
+        if len(self.sections[PRE_CONFIG]) > 0:
+            doc_string += self.sections[PRE_CONFIG]
+
+        if len(self.sections[CONFIG]) > 0:
+            doc_string += '\n#### config\n'
+            doc_string += '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  json\n'
+            doc_string += self.pretty_json(self.sections[CONFIG])+'\n'
+            doc_string += '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
+        else:
+            # doc_string += '#### config/\n'
+            pass
+
+        if len(self.sections[POST_CONFIG]) > 0:
+            doc_string += self.sections[POST_CONFIG]
+
+        if len(self.sections[PREDICT]) > 0:
+            doc_string += '\n#### predict\n'
+            doc_string += '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  json\n'
+            doc_string += self.pretty_json(self.sections[PREDICT])+'\n'
+            doc_string += '\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
+        else:
+            # doc_string += '#### predict/\n'
+            pass
+
+        if len(self.sections[POST_PREDICT]) > 0:
+            doc_string += self.sections[POST_PREDICT]
+
+        return doc_string
+
+
+
+
+
+
 
