@@ -2,7 +2,11 @@ import logging
 import os
 import re
 
-from _dd_interface import *
+from _dd_interface import DrivenDoc
+from _dd_interface import PRE_CONFIG, CONFIG, POST_CONFIG
+from _dd_interface import PREDICT, POST_PREDICT, RESPONSE, POST_RESPONSE
+from _dd_interface import RUNTIME, POST_RUNTIME, REPORT, POST_REPORT
+
 
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
@@ -90,13 +94,14 @@ def feed_line(driven_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl):
 def print_to_files(driven_doc, include_response=True):
     # first we calculate what the important directories are
     status_dir = os.path.join(driven_doc.root_dir, 'status/')
-    pdf_dir = os.path.join(driven_doc.root_dir, 'pdf/')
+    pub_dir = os.path.join(driven_doc.root_dir, 'publish/')
 
     # we also calculate some of the filenames that we know we will use
     bare_filename = driven_doc.filename[:len(driven_doc.filename)-3]
+    log.warning('bare_filename: '+bare_filename)
     status_filename = os.path.join(status_dir, bare_filename+'.status')
     ch_status_filename = os.path.join(status_dir, bare_filename+'.ch.status')
-    pre_pdf_all_filename = os.path.join(pdf_dir, bare_filename+'.all.dd')
+    pre_pdf_all_filename = os.path.join(pub_dir, bare_filename+'.all.dd')
 
     # first we print the pre-pdf .all.dd file
     pre_pdf_all_file = open(pre_pdf_all_filename, 'w')
@@ -107,7 +112,7 @@ def print_to_files(driven_doc, include_response=True):
     # DrivenDoc creating a filename.nav.dd file in which each chapter is in
     # its own file in the chapter directory and each json/code snippet is in
     # one of the sub-directories of the chapter directory.
-    driven_doc.print_nav_to_file()
+    # driven_doc.print_nav_to_file()
 
     # next we delete the .status files that have this bare_filename.
     # we do this in case they were created the last time we ran the program.
@@ -130,7 +135,7 @@ def delete_file(full_filepath):
         os.remove(full_filepath) # delete it if it already existed
     except:
        pass
-    open(report_filepath, 'w').close()
+    open(full_filepath, 'w').close()
     try:
         os.remove(full_filepath) # delete it if it already existed
     except:
