@@ -5,11 +5,12 @@ default_base_url='http://216.224.141.220:5438'
 default_http_headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
 def get_docdriven_testcase(driven_doc, base_url=default_base_url, http_headers=default_http_headers):
 
+    DocDrivenTestCase.remove_test_methods()
     # REMOVE TEST CASES FROM LAST TIME -- EACH INIT SHOULD BE FRESH
 
     DocDrivenTestCase.driven_doc = driven_doc
-    DocDrivenTestCase.default_base_url = base_url
-    DocDrivenTestCase.default_http_headers = http_headers
+    # DocDrivenTestCase.default_base_url = base_url
+    # DocDrivenTestCase.default_http_headers = http_headers
 
     # we dont want a class with no tests, because then
     # the introduction/conclusion won't get run
